@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "hatty" "1.3.0"
+(define-package "hatty" "20250414.2155"
   "Query positions through hats."
   '((emacs "29.1"))
   :url "https://github.com/ErikPrantare/hatty.el"
